<?php

/**
 * @file
 * Extension of the Views Plugin Style for D3 Map.
 */

/**
 * Extended class of D3map views plugin style.
 */
class d3map_region_views_plugin_style extends d3map_views_plugin_style {

  /**
   * Set default options.
   */
  public function option_definition() {
    $options = parent::option_definition();
    $options['filter'] = array('default' => 'region');

    return $options;
  }

  /**
   * Renders D3 map view.
   */
  public function render() {
    if (!empty($this->view->live_preview)) {
      return t('No preview available');
    }
    $data = array();
    $content = array();

    // Is there a data field selected?
    if ($this->options['data_source']) {
      $this->render_fields($this->view->result);
      foreach ($this->view->result as $id => $result) {
        $datafield = $this->get_field_value($id, $this->options['data_source']);

        if (!empty($datafield)) {
          // Set shape var to the rendered data field item.
          $shape = $this->rendered_fields[$id][$this->options['data_source']];

          // Let modules modify the shape data.
          drupal_alter('d3map_views_alter_shape_data', $result, $shape);

          // If field is a taxonomy field use the tid value.
          $field_value = (isset($datafield[0]['tid'])) ? $datafield[0]['tid'] : $shape;

          // Add this shape identifiers into the $data array for map rendering:
          $data[$shape] = $field_value;
        }
      }

      // Remove duplicate shape identifiers.
      $data = array_unique($data);

      // If no data and hide_empty option is selected return nothing.
      if (empty($data) && !empty($this->options['hide_empty'])) {
        return '';
      }

      // Set settings values and store these values as JS settings.
      $d3map_views_settings = array(
        'width' => $this->options['width'],
        'height' => $this->options['height'],
        'activePaths' => json_encode($data, JSON_FORCE_OBJECT),
        'mapPath' => drupal_get_path('module', 'd3map_views') . '/maps/us.json',
        'paramName' => $this->options['filter'],
        'showTerritories' => $this->options['territories'],
      );

      // Get the D3 include path from loading the D3 library.
      $d3_include_path = d3map_views_d3_include_path();

      $content = array(
        'd3map_region_views' => array(
          '#theme' => 'd3map_views_map',
          '#width' => $this->options['width'] . 'px',
          'height' => $this->options['height'] . 'px',
        ),
        '#attached' => array(
          'js' => array(
            $d3_include_path->uri,
            drupal_get_path('module', 'd3map_region_views') . '/js/d3map.js' => array('scope' => 'footer'),
          ),
          'css' => array(
            drupal_get_path('module', 'd3map_views') . '/css/d3map.css',
          ),
        ),
      );
      $content['#attached']['js'][] = array(
        'data' => array('d3map_views' => $d3map_views_settings),
        'type' => 'setting',
      );
    }
    return $content;
  }

}
